import React from "react";
import styles from "./index.css";
import { getData } from "../../api/index";
import Box from "../../components/Box/index.jsx";
import Title from "../../components/Title/index.jsx";
import { LevelList2 } from "../../components/LeveList2/index.jsx";
import EditTpl from "../../components/edit/index";

import { LevelList1 } from '../../components/LevelList1/index.jsx';
import { NumTostring } from '../../components/numTostring';


class Industry extends React.Component {
    state = {
        //商品列表 搜索 接口配置
        productListData: {
            data: {
                list: []
            }
        },
        //搜索框
        inputValue: "",
        //分类数据
        classificationListData: {
            data: {
                list: []
            }
        },
        ProductDetailsData: {
            data: {

            }
        },
        //产品轮播下标
        productSubscript:0
    }

    //搜索功能
    searTime = null;
    searchValue = e => {
        e.persist();
        const search = e.target.value || '';
        this.setState({
            inputValue: search
        });
        clearTimeout(this.searTime);
        this.searTime = setTimeout(() => {
            this.searchDealWith({
                search
            });
        }, 800);
    }

    //搜索函数
    searchDealWith(e = {}) {
        const {
            match: {
                params = {}
            }
        } = this.props;
        //商品列表 搜索 接口配置 productListData
        getData({
            port: "productListData",
            ...params,
            params: {
                pageNum: 1,
                pageSize: 50,
                ...e
            }
        }).then(res => {
            const { config, config: {
                data: {
                    list = []
                }
            } } = res;
            this.setState({ productListData: config });
            this.getProductDetails(list[0] || {},0);
            list.length && this.startProductCarousel();
        });
    }
    //分类查询
    classification = e => {
        const {
            match: {
                params = {}
            }
        } = this.props;
        getData({
            port: "classificationListData",
            ...params
        }).then(res => {
            const { config, config: {
                data: {
                    list = []
                }
            } } = res;
            this.setState({ classificationListData: config });
            this.searchDealWith({
                typeId: (list[0] || {}).id || ''
            });
        });
    }
    //获取详情
    getProductDetails = (e = {},productSubscript) => {
        const {
            match: {
                params = {}
            }
        } = this.props;
        this.setState({productSubscript});
        return getData({
            port: "ProductDetailsData",
            ...params,
            params: {
                ...e
            }
        }).then(res => {
            const { config } = res;
            this.setState({ ProductDetailsData: config ,productSubscript});
        });
    }

    carouselTime = null;
    //start启动产品轮播
    startProductCarousel = e =>{
        clearTimeout(this.carouselTime);
        this.carouselTime = setTimeout(e=>{
            const {
                data: {
                    list = []
                }
            } = this.state.productListData;
            const index = this.state.productSubscript<list.length-1?this.state.productSubscript+1:0;
            this.getProductDetails(list[index],index).then(e=>{
                this.startProductCarousel();
            });
        },5000);
    }

    componentDidMount() {
        this.classification();
    }

    componentWillUnmount() {
        //组件销毁
        clearTimeout(this.carouselTime);
    }
    render() {
        const {productSubscript, classificationListData, productListData, inputValue,ProductDetailsData, ProductDetailsData: { data: DetailsData } } = this.state,
            p_list = (((productListData || {}).data || {}).list || []);
        const PovertyAlleviationArticle = {
            data: {
                list: ['brandName', 'spec', 'qualityGuaranteePeriod', 'placeOfProduction', 'umsCompanyInfo'].map((x, i) => {
                    const name = DetailsData[x];
                    if (name) {
                        return {
                            title: DetailsData[`minTitle${i + 1}`],
                            name
                        }
                    }
                }).filter(x => {
                    if (x) return x;
                })
            }
        };
        return (
            <div className={styles.Box}>
                <div className={styles.Left}>
                    <Box no={true} style={{ height: "100%" }} className={styles.LeftBox}>
                        <EditTpl
                            style={{
                                bottom: "auto"
                            }}
                            data={productListData}
                            upData={productListData => this.setState({ productListData })}></EditTpl>
                        <div className={styles.searchBox}>
                            <i className={`iconfont icon-sousuo ${styles.iconSearch}`}></i>
                            <input placeholder="输入名称" className={styles.searchText} onChange={e => this.searchValue(e)} />
                        </div>
                        {!inputValue ? <LevelList1 style={{ position: "relative", flex: "none" }} data={classificationListData} active={({ id }) => this.searchDealWith({ typeId: id })} ></LevelList1> : ''}
                        {p_list.length ? <ul className={styles.ulList}>
                            {p_list.map((x, i) => {
                                return (<li key={i} onClick={e=>this.getProductDetails(x,i)}>
                                    <div className={`${styles.ulListItem} ${productSubscript == i?styles.hover:''}`}>
                                        <div className={styles.img} style={{ backgroundImage: `url(${x.pic})` }}></div>
                                        <h3>{x.name}</h3>
                                        <div className={"level-line"}></div>
                                        <div className={styles.itemText}>
                                            {x.brandName ? <span>品牌：{x.brandName}</span> : ''}
                                            {x.price ? <span>零售价：{x.price}</span> : ''}
                                        </div>
                                        {x.umsCompanyInfo ? <div className={styles.itemText}>
                                            <span>供应商：{x.umsCompanyInfo || ''}</span>
                                        </div> : ''}
                                    </div>
                                </li>)
                            })}
                        </ul> : <div className={styles.NoData}>没有数据</div>}
                    </Box>
                </div>
                <Box className={styles.Right} no={true}>
                    <EditTpl data={ProductDetailsData} upData={ProductDetailsData => this.setState({ProductDetailsData})}></EditTpl>
                    <div className={styles.RightBox}>
                        <Box style={{ height: "58%", display: "flex" }}>
                            <div className={styles.productImges} style={{ backgroundImage: `url(${DetailsData.pic})` }}></div>
                            <div className={styles.productHref}>
                                <div className={styles.retailPrice}>{DetailsData.retailPriceTitle}</div>
                                <div className={styles.NumTostring}>{DetailsData.priceIcon}<NumTostring>{DetailsData.price || ''}</NumTostring></div>
                                <div className={styles.retailPrice}>{DetailsData.PurchaseLinkTitle}</div>
                                <div className={styles.BuyLink}>
                                    {(DetailsData.buyList || []).map((x, i) => {
                                        return (<img key={i} src={x.icon} />)
                                    })}
                                </div>
                            </div>
                        </Box>
                        <br />
                        <Title>{DetailsData.name}</Title>
                        <br />
                        <LevelList2 data={PovertyAlleviationArticle}></LevelList2>
                        <br />
                        <Box no={true} style={{ flex: 1 }}>
                            <Title>{DetailsData.IntroductionTitle}</Title>
                            <div className={styles.IntroductionInfo}>
                                {DetailsData.description}
                            </div>
                        </Box>
                    </div>
                </Box>
            </div>
        )
    }
}
export {
    Industry
}
export default Industry